@@ -8,7 +8,7 @@ __all__ = [
     'ArbitrationError', 'NoSuchBuildIdentityError', 'InternalError', 'DeveloperModeIsNotEnabledError',
     'DeviceAlreadyInUseError', 'LockdownError', 'PairingDialogResponsePendingError', 'UserDeniedPairingError',
     'InvalidHostIDError', 'SetProhibitedError', 'MissingValueError', 'PasscodeRequiredError', 'AmfiError',
-    'DeviceHasPasscodeSetError', 'NotificationTimeoutError',
+    'DeviceHasPasscodeSetError', 'NotificationTimeoutError', 'DeveloperModeError',
 ]
 
 
@@ -177,6 +177,11 @@ class DeveloperModeIsNotEnabledError(PyMobileDevice3Exception):
     pass
 
 
+class DeveloperModeError(PyMobileDevice3Exception):
+    """ Raise when amfid failed to enable developer mode. """
+    pass
+
+
 class LockdownError(PyMobileDevice3Exception):
     """ lockdown general error """
     pass
