@@ -1,7 +1,8 @@
 import plistlib
 
 from cached_property import cached_property
-from pymobiledevice3.exceptions import PyMobileDevice3Exception
+
+from pymobiledevice3.exceptions import NoSuchBuildIdentityError
 from pymobiledevice3.restore.ipsw.build_identity import BuildIdentity
 
 
@@ -36,11 +37,21 @@ class BuildManifest:
         else:
             raise ValueError()
 
-    def get_build_identity(self, device_class: str, restore_behavior: str):
+    def get_build_identity(self, device_class: str, restore_behavior: str = None, variant: str = None):
         for build_identity in self._build_identities:
-            if build_identity.device_class == device_class and build_identity.restore_behavior == restore_behavior:
-                return build_identity
-        raise PyMobileDevice3Exception('failed to find the correct BuildIdentity from the BuildManifest')
+            if variant is not None:
+                if variant not in build_identity.variant:
+                    continue
+
+            if build_identity.device_class != device_class:
+                continue
+
+            if restore_behavior is not None:
+                if build_identity.restore_behavior != restore_behavior:
+                    continue
+
+            return build_identity
+        raise NoSuchBuildIdentityError('failed to find the correct BuildIdentity from the BuildManifest')
 
     def _parse_build_identities(self):
         self._build_identities = []
